summaryrefslogtreecommitdiff
path: root/xmake/scripts
diff options
context:
space:
mode:
authorruki <[email protected]>2024-06-14 22:39:06 +0800
committerruki <[email protected]>2024-06-14 22:39:06 +0800
commit44daa72100eff20fca36cefe898c86306e5651de (patch)
treefef474f5bac5dddf568ce6d3dc82a6e8dda55884 /xmake/scripts
parentff6a2cbe45b52d618e8f2a71f4579d43a980accb (diff)
improve debian copyright
Diffstat (limited to 'xmake/scripts')
-rw-r--r--xmake/scripts/xpack/deb/debian/README.Debian2
-rw-r--r--xmake/scripts/xpack/deb/debian/README.source2
-rw-r--r--xmake/scripts/xpack/deb/debian/changelog2
-rw-r--r--xmake/scripts/xpack/deb/debian/control12
-rw-r--r--xmake/scripts/xpack/deb/debian/copyright38
-rw-r--r--xmake/scripts/xpack/deb/debian/manpage.1.ex10
-rw-r--r--xmake/scripts/xpack/deb/debian/manpage.md.ex18
-rw-r--r--xmake/scripts/xpack/deb/debian/manpage.sgml.ex4
-rw-r--r--xmake/scripts/xpack/deb/debian/manpage.xml.ex6
-rw-r--r--xmake/scripts/xpack/deb/debian/postinst.ex2
-rw-r--r--xmake/scripts/xpack/deb/debian/postrm.ex2
-rw-r--r--xmake/scripts/xpack/deb/debian/preinst.ex2
-rw-r--r--xmake/scripts/xpack/deb/debian/prerm.ex2
-rw-r--r--xmake/scripts/xpack/deb/debian/watch.ex14
-rw-r--r--xmake/scripts/xpack/deb/debian/xmake.cron.d.ex4
-rw-r--r--xmake/scripts/xpack/deb/debian/xmake.doc-base.ex18
16 files changed, 55 insertions, 83 deletions
diff --git a/xmake/scripts/xpack/deb/debian/README.Debian b/xmake/scripts/xpack/deb/debian/README.Debian
index 63e5e1fff..a2a960614 100644
--- a/xmake/scripts/xpack/deb/debian/README.Debian
+++ b/xmake/scripts/xpack/deb/debian/README.Debian
@@ -1,4 +1,4 @@
-xmake for Debian
+${PACKAGE_NAME} for Debian
---------------
<possible notes regarding this package - if none, delete this file>
diff --git a/xmake/scripts/xpack/deb/debian/README.source b/xmake/scripts/xpack/deb/debian/README.source
index 73bb89bfe..69506a7dd 100644
--- a/xmake/scripts/xpack/deb/debian/README.source
+++ b/xmake/scripts/xpack/deb/debian/README.source
@@ -1,4 +1,4 @@
-xmake for Debian
+${PACKAGE_NAME} for Debian
---------------
<this file describes information about the source package, see Debian policy
diff --git a/xmake/scripts/xpack/deb/debian/changelog b/xmake/scripts/xpack/deb/debian/changelog
index e34fb09b7..f583d964f 100644
--- a/xmake/scripts/xpack/deb/debian/changelog
+++ b/xmake/scripts/xpack/deb/debian/changelog
@@ -2,4 +2,4 @@ ${PACKAGE_NAME} (${PACKAGE_VERSION}-1) UNRELEASED; urgency=medium
* Initial release (Closes: #nnnn) <nnnn is the bug number of your ITP>
- -- unknown <[email protected]> Thu, 13 Jun 2024 01:47:13 +0000
+ -- ${PACKAGE_MAINTAINER} ${PACKAGE_DATE}
diff --git a/xmake/scripts/xpack/deb/debian/control b/xmake/scripts/xpack/deb/debian/control
index 37845914b..1443bb33e 100644
--- a/xmake/scripts/xpack/deb/debian/control
+++ b/xmake/scripts/xpack/deb/debian/control
@@ -1,16 +1,16 @@
-Source: xmake
+Source: ${PACKAGE_NAME}
Section: unknown
Priority: optional
-Maintainer: unknown <[email protected]>
+Maintainer: ${PACKAGE_MAINTAINER}
Build-Depends: debhelper-compat (= 13)
Standards-Version: 4.6.0
-Homepage: <insert the upstream URL, if relevant>
+Homepage: ${PACKAGE_HOMEPAGE}
#Vcs-Browser: https://salsa.debian.org/debian/xmake
#Vcs-Git: https://salsa.debian.org/debian/xmake.git
Rules-Requires-Root: no
-Package: xmake
+Package: ${PACKAGE_NAME}
Architecture: any
Depends: ${shlibs:Depends}, ${misc:Depends}
-Description: <insert up to 60 chars description>
- <insert long description, indented with spaces>
+Description: ${PACKAGE_TITLE}
+ ${PACKAGE_DESCRIPTION}
diff --git a/xmake/scripts/xpack/deb/debian/copyright b/xmake/scripts/xpack/deb/debian/copyright
index 67aff9179..0056dbd39 100644
--- a/xmake/scripts/xpack/deb/debian/copyright
+++ b/xmake/scripts/xpack/deb/debian/copyright
@@ -1,38 +1,10 @@
Format: https://www.debian.org/doc/packaging-manuals/copyright-format/1.0/
-Upstream-Name: xmake
-Upstream-Contact: <preferred name and address to reach the upstream project>
-Source: <url://example.com>
+Upstream-Name: ${PACKAGE_NAME}
+Upstream-Contact: ${PACKAGE_AUTHOR}
+Source: ${PACKAGE_HOMEPAGE}
Files: *
-Copyright: <years> <put author's name and email here>
- <years> <likewise for another author>
-License: Apache-2.0
-
-Files: debian/*
-Copyright: 2024 unknown <[email protected]>
-License: Apache-2.0
-
-License: Apache-2.0
- Licensed under the Apache License, Version 2.0 (the "License");
- you may not use this file except in compliance with the License.
- You may obtain a copy of the License at
- .
- https://www.apache.org/licenses/LICENSE-2.0
- .
- Unless required by applicable law or agreed to in writing, software
- distributed under the License is distributed on an "AS IS" BASIS,
- WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- See the License for the specific language governing permissions and
- limitations under the License.
+Copyright: ${PACKAGE_COPYRIGHT}
+License: ${PACKAGE_LICENSE}
.
- On Debian systems, the complete text of the Apache version 2.0 license
- can be found in "/usr/share/common-licenses/Apache-2.0".
-# Please also look if there are files or directories which have a
-# different copyright/license attached and list them here.
-# Please avoid picking licenses with terms that are more restrictive than the
-# packaged work, as it may make Debian's contributions unacceptable upstream.
-#
-# If you need, there are some extra license texts available in two places:
-# /usr/share/debhelper/dh_make/licenses/
-# /usr/share/common-licenses/
diff --git a/xmake/scripts/xpack/deb/debian/manpage.1.ex b/xmake/scripts/xpack/deb/debian/manpage.1.ex
index e917987a2..e67d3f418 100644
--- a/xmake/scripts/xpack/deb/debian/manpage.1.ex
+++ b/xmake/scripts/xpack/deb/debian/manpage.1.ex
@@ -4,7 +4,7 @@
.\" First parameter, NAME, should be all caps
.\" Second parameter, SECTION, should be 1-8, maybe w/ subsection
.\" other parameters are allowed: see man(7), man(1)
-.TH Xmake SECTION "June 13 2024"
+.TH ${PACKAGE_NAME} SECTION "June 13 2024"
.\" Please adjust this date whenever revising the manpage.
.\"
.\" Some roff macros, for reference:
@@ -18,16 +18,16 @@
.\" .sp <n> insert n+1 empty lines
.\" for manpage-specific macros, see man(7)
.SH NAME
-xmake \- program to do something
+${PACKAGE_NAME} \- program to do something
.SH SYNOPSIS
-.B xmake
+.B ${PACKAGE_NAME}
.RI [ options ] " files" ...
.br
.B bar
.RI [ options ] " files" ...
.SH DESCRIPTION
This manual page documents briefly the
-.B xmake
+.B ${PACKAGE_NAME}
and
.B bar
commands.
@@ -35,7 +35,7 @@ commands.
.\" TeX users may be more comfortable with the \fB<whatever>\fP and
.\" \fI<whatever>\fP escape sequences to invode bold face and italics,
.\" respectively.
-\fBxmake\fP is a program that...
+\fB${PACKAGE_NAME}\fP is a program that...
.SH OPTIONS
These programs follow the usual GNU command line syntax, with long
options starting with two dashes (`-').
diff --git a/xmake/scripts/xpack/deb/debian/manpage.sgml.ex b/xmake/scripts/xpack/deb/debian/manpage.sgml.ex
index 6415ba5e4..643323878 100644
--- a/xmake/scripts/xpack/deb/debian/manpage.sgml.ex
+++ b/xmake/scripts/xpack/deb/debian/manpage.sgml.ex
@@ -26,8 +26,8 @@ manpage.1: manpage.sgml
<!ENTITY dhsection "<manvolnum>SECTION</manvolnum>">
<!ENTITY dhemail "<email>[email protected]</email>">
<!ENTITY dhusername "unknown">
- <!ENTITY dhucpackage "<refentrytitle>Xmake</refentrytitle>">
- <!ENTITY dhpackage "xmake">
+ <!ENTITY dhucpackage "<refentrytitle>${PACKAGE_NAME}</refentrytitle>">
+ <!ENTITY dhpackage "${PACKAGE_NAME}">
<!ENTITY debian "<productname>Debian</productname>">
<!ENTITY gnu "<acronym>GNU</acronym>">
diff --git a/xmake/scripts/xpack/deb/debian/manpage.xml.ex b/xmake/scripts/xpack/deb/debian/manpage.xml.ex
index 8c5acfd8b..a1ea2e951 100644
--- a/xmake/scripts/xpack/deb/debian/manpage.xml.ex
+++ b/xmake/scripts/xpack/deb/debian/manpage.xml.ex
@@ -56,9 +56,9 @@ man(1), man(7), http://www.tldp.org/HOWTO/Man-Page/
<!ENTITY dhsection "SECTION">
<!-- TITLE should be something like "User commands" or similar (see
http://www.tldp.org/HOWTO/Man-Page/q2.html). -->
- <!ENTITY dhtitle "xmake User Manual">
- <!ENTITY dhucpackage "Xmake">
- <!ENTITY dhpackage "xmake">
+ <!ENTITY dhtitle "${PACKAGE_NAME} User Manual">
+ <!ENTITY dhucpackage "${PACKAGE_NAME}">
+ <!ENTITY dhpackage "${PACKAGE_NAME}">
]>
<refentry>
diff --git a/xmake/scripts/xpack/deb/debian/postinst.ex b/xmake/scripts/xpack/deb/debian/postinst.ex
index fc0e76bfd..768815777 100644
--- a/xmake/scripts/xpack/deb/debian/postinst.ex
+++ b/xmake/scripts/xpack/deb/debian/postinst.ex
@@ -1,5 +1,5 @@
#!/bin/sh
-# postinst script for xmake
+# postinst script for ${PACKAGE_NAME}
#
# see: dh_installdeb(1)
diff --git a/xmake/scripts/xpack/deb/debian/postrm.ex b/xmake/scripts/xpack/deb/debian/postrm.ex
index f8e19bae9..9f6a219b7 100644
--- a/xmake/scripts/xpack/deb/debian/postrm.ex
+++ b/xmake/scripts/xpack/deb/debian/postrm.ex
@@ -1,5 +1,5 @@
#!/bin/sh
-# postrm script for xmake
+# postrm script for ${PACKAGE_NAME}
#
# see: dh_installdeb(1)
diff --git a/xmake/scripts/xpack/deb/debian/preinst.ex b/xmake/scripts/xpack/deb/debian/preinst.ex
index 2809c5af4..bc61d7f9d 100644
--- a/xmake/scripts/xpack/deb/debian/preinst.ex
+++ b/xmake/scripts/xpack/deb/debian/preinst.ex
@@ -1,5 +1,5 @@
#!/bin/sh
-# preinst script for xmake
+# preinst script for ${PACKAGE_NAME}
#
# see: dh_installdeb(1)
diff --git a/xmake/scripts/xpack/deb/debian/prerm.ex b/xmake/scripts/xpack/deb/debian/prerm.ex
index da70686aa..4b920862b 100644
--- a/xmake/scripts/xpack/deb/debian/prerm.ex
+++ b/xmake/scripts/xpack/deb/debian/prerm.ex
@@ -1,5 +1,5 @@
#!/bin/sh
-# prerm script for xmake
+# prerm script for ${PACKAGE_NAME}
#
# see: dh_installdeb(1)
diff --git a/xmake/scripts/xpack/deb/debian/watch.ex b/xmake/scripts/xpack/deb/debian/watch.ex
index 399b96141..71247936b 100644
--- a/xmake/scripts/xpack/deb/debian/watch.ex
+++ b/xmake/scripts/xpack/deb/debian/watch.ex
@@ -11,28 +11,28 @@ version=4
# HTTP site (basic)
#http://example.com/downloads.html \
-# files/xmake-([\d\.]+)\.tar\.gz debian uupdate
+# files/${PACKAGE_NAME}-([\d\.]+)\.tar\.gz debian uupdate
# Uncomment to examine an FTP server
-#ftp://ftp.example.com/pub/xmake-(.*)\.tar\.gz debian uupdate
+#ftp://ftp.example.com/pub/${PACKAGE_NAME}-(.*)\.tar\.gz debian uupdate
# SourceForge hosted projects
-# http://sf.net/xmake/ xmake-(.*)\.tar\.gz debian uupdate
+# http://sf.net/${PACKAGE_NAME}/ ${PACKAGE_NAME}-(.*)\.tar\.gz debian uupdate
# GitHub hosted projects
#opts="filenamemangle=s%(?:.*?)?v?(\d[\d.]*)\.tar\.gz%<project>-$1.tar.gz%" \
-# https://github.com/<user>/xmake/tags \
+# https://github.com/<user>/${PACKAGE_NAME}/tags \
# (?:.*?/)?v?(\d[\d.]*)\.tar\.gz debian uupdate
# PyPI
-# https://pypi.debian.net/xmake/xmake-(.+)\.(?:zip|tgz|tbz|txz|(?:tar\.(?:gz|bz2|xz)))
+# https://pypi.debian.net/${PACKAGE_NAME}/${PACKAGE_NAME}-(.+)\.(?:zip|tgz|tbz|txz|(?:tar\.(?:gz|bz2|xz)))
# Direct Git
-# opts="mode=git" http://git.example.com/xmake.git \
+# opts="mode=git" http://git.example.com/${PACKAGE_NAME}.git \
# refs/tags/v([\d\.]+) debian uupdate
# Uncomment to find new files on GooglePages
-# http://example.googlepages.com/foo.html xmake-(.*)\.tar\.gz
+# http://example.googlepages.com/foo.html ${PACKAGE_NAME}-(.*)\.tar\.gz
diff --git a/xmake/scripts/xpack/deb/debian/xmake.doc-base.ex b/xmake/scripts/xpack/deb/debian/xmake.doc-base.ex
index 43f406e63..1dda4d3da 100644
--- a/xmake/scripts/xpack/deb/debian/xmake.doc-base.ex
+++ b/xmake/scripts/xpack/deb/debian/xmake.doc-base.ex
@@ -1,20 +1,20 @@
-Document: xmake
-Title: Debian xmake Manual
-Author: <insert document author here>
-Abstract: This manual describes what xmake is
+Document: ${PACKAGE_NAME}
+Title: Debian ${PACKAGE_NAME} Manual
+Author: ${PACKAGE_AUTHOR}
+Abstract: This manual describes what ${PACKAGE_NAME} is
and how it can be used to
manage online manuals on Debian systems.
Section: unknown
Format: debiandoc-sgml
-Files: /usr/share/doc/xmake/xmake.sgml.gz
+Files: /usr/share/doc/${PACKAGE_NAME}/${PACKAGE_NAME}.sgml.gz
Format: postscript
-Files: /usr/share/doc/xmake/xmake.ps.gz
+Files: /usr/share/doc/${PACKAGE_NAME}/${PACKAGE_NAME}.ps.gz
Format: text
-Files: /usr/share/doc/xmake/xmake.text.gz
+Files: /usr/share/doc/${PACKAGE_NAME}/${PACKAGE_NAME}.text.gz
Format: HTML
-Index: /usr/share/doc/xmake/html/index.html
-Files: /usr/share/doc/xmake/html/*.html
+Index: /usr/share/doc/${PACKAGE_NAME}/html/index.html
+Files: /usr/share/doc/${PACKAGE_NAME}/html/*.html
diff --git a/xmake/scripts/xpack/deb/debian/manpage.md.ex b/xmake/scripts/xpack/deb/debian/manpage.md.ex
index daab8891f..532df2807 100644
--- a/xmake/scripts/xpack/deb/debian/manpage.md.ex
+++ b/xmake/scripts/xpack/deb/debian/manpage.md.ex
@@ -1,4 +1,4 @@
-% xmake(SECTION) | User Commands
+% ${PACKAGE_NAME}(SECTION) | User Commands
%
% "June 13 2024"
@@ -25,24 +25,24 @@
# NAME
-xmake - program to do something
+${PACKAGE_NAME} - program to do something
# SYNOPSIS
-**xmake** **-e** _this_ [**\-\-example=that**] [{**-e** | **\-\-example**} _this_]
+**${PACKAGE_NAME}** **-e** _this_ [**\-\-example=that**] [{**-e** | **\-\-example**} _this_]
[{**-e** | **\-\-example**} {_this_ | _that_}]
-**xmake** [{**-h** | *\-\-help**} | {**-v** | **\-\-version**}]
+**${PACKAGE_NAME}** [{**-h** | *\-\-help**} | {**-v** | **\-\-version**}]
# DESCRIPTION
-This manual page documents briefly the **xmake** and **bar** commands.
+This manual page documents briefly the **${PACKAGE_NAME}** and **bar** commands.
This manual page was written for the Debian distribution because the
original program does not have a manual page. Instead, it has documentation
in the GNU info(1) format; see below.
-**xmake** is a program that...
+**${PACKAGE_NAME}** is a program that...
# OPTIONS
@@ -63,11 +63,11 @@ a complete description, see the **info**(1) files.
/etc/foo.conf
: The system-wide configuration file to control the behaviour of
- xmake. See **foo.conf**(5) for further details.
+ ${PACKAGE_NAME}. See **foo.conf**(5) for further details.
${HOME}/.foo.conf
: The per-user configuration file to control the behaviour of
- xmake. See **foo.conf**(5) for further details.
+ ${PACKAGE_NAME}. See **foo.conf**(5) for further details.
# ENVIRONMENT
@@ -83,7 +83,7 @@ Bad configuration file. Exiting.
: The configuration file seems to contain a broken configuration
line. Use the **\-\-verbose** option, to get more info.
**xmake** provides some return codes, that can be used in scripts:
Code Diagnostic
0 Program exited successfully.
@@ -83,7 +83,7 @@ Bad configuration file. Exiting.
: The configuration file seems to contain a broken configuration
line. Use the **\-\-verbose** option, to get more info.
-**xmake** provides some return codes, that can be used in scripts:
+**${PACKAGE_NAME}** provides some return codes, that can be used in scripts:
Code Diagnostic
0 Program exited successfully.
diff --git a/xmake/scripts/xpack/deb/debian/xmake.cron.d.ex b/xmake/scripts/xpack/deb/debian/xmake.cron.d.ex
index dde8dd443..9861593f3 100644
--- a/xmake/scripts/xpack/deb/debian/xmake.cron.d.ex
+++ b/xmake/scripts/xpack/deb/debian/xmake.cron.d.ex
@@ -1,4 +1,4 @@
#
# Regular cron jobs for the xmake package
#
-0 4 * * * root [ -x /usr/bin/xmake_maintenance ] && /usr/bin/xmake_maintenance
+0 4 * * * root [ -x /usr/bin/${PACKAGE_NAME}_maintenance ] && /usr/bin/${PACKAGE_NAME}_maintenance
@@ -1,4 +1,4 @@
#
-# Regular cron jobs for the xmake package
+# Regular cron jobs for the ${PACKAGE_NAME} package
#